=====================
Developer Information
=====================

Programming HowTos and Tutorials
================================

.. toctree::
   :maxdepth: 2

   development-guidelines
   development-environment
   devstack
   dashboard-dev-environment-guide
   how-to-build-oozie
   adding-database-migrations
   testing
   log-guidelines
   apiv2
   image-gen

Other Resources
===============

.. toctree::
   :maxdepth: 2

   contributing
   gerrit
   jenkins
